@@ -27,7 +27,7 @@ def consoleLabel(deduper): # pragma : no cover
             labeled = False
 
             for pair in record_pair:
-                for field in deduper.data_model.comparison_fields:
+                for field in deduper.data_model.field_comparators :
                     line = "%s : %s\n" % (field, pair[field])
                     sys.stderr.write(line)
                 sys.stderr.write('\n')
