@@ -4,8 +4,10 @@
 import re
 import math
 
-words = re.compile("[\w']+")
-integers = re.compile("\d+")
+from dedupe.cpredicates import ngrams, initials
+
+words = re.compile("[\w']+").findall
+integers = re.compile("\d+").findall
 
 def wholeFieldPredicate(field):
     """return the whole field"""
@@ -17,34 +19,23 @@ def wholeFieldPredicate(field):
 
 def tokenFieldPredicate(field):
     """returns the tokens"""
-    return tuple(words.findall(field))
+    return set(words(field))
 
 def commonIntegerPredicate(field):
     """return any integers"""
-    return tuple(integers.findall(field))
+    return set(integers(field))
 
 def nearIntegersPredicate(field):
     """return any integers N, N+1, and N-1"""
-    ints = sorted([int(i) for i in integers.findall(field)])
-    near_ints = set([])
-    [near_ints.update((unicode(i - 1), 
-                       unicode(i), 
-                       unicode(i + 1))) for i in ints]
-    return tuple(near_ints)
-
-def ngrams(field, n):
-    """ngrams returns all unique, contiguous sequences of n characters
-    of a given field.
+    ints = integers(field)
+    near_ints = set(ints)
+    for char in ints :
+        num = int(char)
+        near_ints.add(unicode(num-1))
+        near_ints.add(unicode(num+1))
         
-    :param field: the string to be 
-    :param n: the number of characters to be included in each gram
-    
-    usage:
-    >>> from dedupe.dedupe.predicated import ngrams
-    >>> ngrams("deduplicate", 3)
-    ('ded', 'edu', 'dup', 'upl', 'pli', 'lic', 'ica', 'cat', 'ate')
-    """
-    return tuple([field[pos:pos + n] for pos in xrange(len(field) - n + 1)])
+    return near_ints
+
     
 def commonFourGram(field):
     """return 4-grams"""
@@ -54,22 +45,6 @@ def commonSixGram(field):
     """return 6-grams"""
     return ngrams(field, 6)
 
-def initials(field, n):
-    """predicate which returns first a tuple containing
-    the first n chars of a field if and only if the
-    field contains at least n characters, or an empty
-    tuple otherwise.
-    
-    :param field: the string 
-    :type n: int, default None
-    
-    usage:
-    >>> initials("dedupe", 7)
-    ()
-    >>> initials("deduplication", 7)
-    ('dedupli', )
-    """
-    return (field[:n], ) if len(field) > n-1 else () 
 
 def sameThreeCharStartPredicate(field):
     """return first three characters"""
